/*********************************************************************
 * Project Harman Car Multimedia System
 * (c) copyright 2014
 * Company Harman Automotive Systems GmbH
 * All rights reserved
 * Secrecy Level STRICTLY CONFIDENTIAL
 **********************************************************************/
/**
 * @author    Prashantha Mallapur
 **********************************************************************/

#ifndef VEHICLEPROPERTYEXT_H
#define VEHICLEPROPERTYEXT_H

#include "nullptr.h"
#include <string>
#include <list>
#include <set>
#include <sstream>
#include <map>
#include <functional>
#include "abstractpropertytype.h"
#include "mappropertytype.hpp"


#include <boost/preprocessor/comma.hpp>

#define PROPERTYTYPE(property, propertyType, baseClass, valueType) \
		class propertyType : public baseClass { \
		public: propertyType(): baseClass(property) {} \
		propertyType(valueType val) : baseClass(property, val) {} \
		using baseClass::operator=; \
};

#define PROPERTYTYPE1(property, propertyType, baseClass, valueType) \
		class propertyType : public baseClass { \
		public: propertyType(): baseClass(#property) {} \
		propertyType(valueType val) : baseClass(#property, val) {} \
};

#define PROPERTYTYPEBASIC(property, valueType) \
		class property ## Type : public BasicPropertyType<valueType> { \
		public: property ## Type(): BasicPropertyType(property) {} \
		property ## Type(valueType val) : BasicPropertyType(property, val) {} \
		using BasicPropertyType<valueType>::operator=; \
};

#define PROPERTYTYPEBASIC1(property, valueType) \
		class property ## Type : public BasicPropertyType<valueType> { \
		public: property ## Type(): BasicPropertyType( #property) {} \
		property ## Type(valueType val) : BasicPropertyType(#property, val) {} \
};

#define PROPERTYTYPENOVAL(property, propertyType, baseClass) \
		class propertyType : public baseClass { \
		public: propertyType(): baseClass(property) {} \
};


class VehiclePropertyExt
{

public:


	static void factory();

	typedef std::string Property;

	typedef std::function<AbstractPropertyType* (void)> PropertyTypeFactoryCallback;

	static const Property NoValue;

	static const Property  Ipc_CanStatus;
	PROPERTYTYPE(Ipc_CanStatus,Ipc_CanStatusType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  cpiSink_Status;
	PROPERTYTYPE(cpiSink_Status,cpiSink_StatusType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property WheelDataForntLeftDirection;
	PROPERTYTYPE(WheelDataForntLeftDirection, WheelDataForntLeftDirectionType, BasicPropertyType<uint16_t>,uint16_t)

	static const Property WheelDataForntRightDirection;
	PROPERTYTYPE(WheelDataForntRightDirection, WheelDataForntRightDirectionType, BasicPropertyType<uint16_t>,uint16_t)

	static const Property WheelDataRearLeftDirection;
	PROPERTYTYPE(WheelDataRearLeftDirection, WheelDataRearLeftDirectionType, BasicPropertyType<uint16_t>,uint16_t)

	static const Property WheelDataRearRightDirection;
	PROPERTYTYPE(WheelDataRearRightDirection, WheelDataRearRightDirectionType, BasicPropertyType<uint16_t>,uint16_t)

	static const Property WheelDataForntLeftSpeed;
	PROPERTYTYPE(WheelDataForntLeftSpeed, WheelDataForntLeftSpeedType, BasicPropertyType<uint16_t>,uint16_t)

	static const Property WheelDataForntRightSpeed;
	PROPERTYTYPE(WheelDataForntRightSpeed, WheelDataForntRightSpeedType, BasicPropertyType<uint16_t>,uint16_t)

	static const Property WheelDataRearLeftSpeed;
	PROPERTYTYPE(WheelDataRearLeftSpeed,WheelDataRearLeftSpeedType, BasicPropertyType<uint16_t>,uint16_t)

	static const Property WheelDataRearRightSpeed;
	PROPERTYTYPE(WheelDataRearRightSpeed, WheelData_RearRightSpeedType, BasicPropertyType<uint16_t>,uint16_t)

	//static const Property BluetoothStrength;
	//PROPERTYTYPE(BluetoothStrength, BluetoothStrengthType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property GlobalClockDay;
	PROPERTYTYPE(GlobalClockDay, GlobalClockDayType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property GlobalClockHour;
	PROPERTYTYPE(GlobalClockHour, GlobalClockHourType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property GlobalClockMinute;
	PROPERTYTYPE(GlobalClockMinute, GlobalClockMinuteType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property GlobalClockSecond;
	PROPERTYTYPE(GlobalClockSecond, GlobalClockSecondType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property GlobalClockYear;
	PROPERTYTYPE(GlobalClockYear, GlobalClockYearType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Ignition_Status;
	PROPERTYTYPE(Ignition_Status, Ignition_StatusType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property EngAout_N_Actl;
	PROPERTYTYPE(EngAout_N_Actl, EngAout_N_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property EngAout_Tq_Actl;
	PROPERTYTYPE(EngAout_Tq_Actl, EngAout_Tq_ActlType, BasicPropertyType<int16_t>, int16_t)


	static const Property ApedPos_Pc_ActlArb;
	PROPERTYTYPE(ApedPos_Pc_ActlArb,ApedPos_Pc_ActlArbType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  DispGlblClkAdj_B_Rq;
	PROPERTYTYPE(DispGlblClkAdj_B_Rq,DispGlblClkAdj_B_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property DispGlblClkDay_No_Rq;
	PROPERTYTYPE(DispGlblClkDay_No_Rq,DispGlblClkDay_No_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  DispGlblClkHr_No_Rq;
	PROPERTYTYPE(DispGlblClkHr_No_Rq,DispGlblClkHr_No_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property DispGlblClkMnte_No_Rq;
	PROPERTYTYPE(DispGlblClkMnte_No_Rq,DispGlblClkMnte_No_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  DispGlblClkScnd_No_Rq;
	PROPERTYTYPE(DispGlblClkScnd_No_Rq,DispGlblClkScnd_No_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  DispGlblClkYr_No_Rq;
	PROPERTYTYPE(DispGlblClkYr_No_Rq,DispGlblClkYr_No_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  Dimming_Lvl;
	PROPERTYTYPE(Dimming_Lvl, Dimming_LvlType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  Litval;
	PROPERTYTYPE(Litval, LitvalType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  Backlit_LED_Status;
	PROPERTYTYPE(Backlit_LED_Status,Backlit_LED_StatusType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  Day_Night_Status;
	PROPERTYTYPE(Day_Night_Status,Day_Night_StatusType, BasicPropertyType<uint16_t>, uint16_t)


	/*********************************** R1.0 ***********************************************************************************/
	/**Rx signal properties **/
	static const Property  DrStatTgate_B_Actl;
	PROPERTYTYPE(DrStatTgate_B_Actl,DrStatTgate_B_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  DrStatDrv_B_Actl;
	PROPERTYTYPE(DrStatDrv_B_Actl,DrStatDrv_B_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  LifeCycMde_D_Actl;
	PROPERTYTYPE(LifeCycMde_D_Actl,LifeCycMde_D_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  Delay_Accy;
	PROPERTYTYPE(Delay_Accy,Delay_AccyType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  Eng_D_Stat;
	PROPERTYTYPE(Eng_D_Stat,Eng_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  RstrnImpactEvntStatus;
	PROPERTYTYPE(RstrnImpactEvntStatus,RstrnImpactEvntStatusType, BasicPropertyType<uint16_t>, uint16_t)

	/*Below are the Rx properties created for messages */
	static const Property  GblClkData;
	PROPERTYTYPE(GblClkData,GblClkDataType, BasicPropertyType<uint32_t>, uint32_t)

	//PROPERTYTYPE(GblClkData,GblClkDataType, ListPropertyType<uint16_t>, uint16_t)


	/*static const Property  IPC_Infotainment;
	PROPERTYTYPE(IPC_Infotainment,IPC_InfotainmentType, ListPropertyType<BasicPropertyType<uint16_t> >, uint16_t)*/

	static const Property  IPC_Infotainment;
	PROPERTYTYPE(IPC_Infotainment,IPC_InfotainmentType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  VehCharacteristic;
	PROPERTYTYPE(VehCharacteristic,VehCharacteristicType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  Battery_Mgmt_2;
	PROPERTYTYPE(Battery_Mgmt_2,Battery_Mgmt_2Type, BasicPropertyType<uint32_t>, uint32_t)

	/**Tx signal properties **/
	static const Property  CamraOvrlDyn_D_Rq;
	PROPERTYTYPE(CamraOvrlDyn_D_Rq,CamraOvrlDyn_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  CamraOvrlStat_D_Rq;
	PROPERTYTYPE(CamraOvrlStat_D_Rq,CamraOvrlStat_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  CamraZoomMan_D_Rq;
	PROPERTYTYPE(CamraZoomMan_D_Rq,CamraZoomMan_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  DistanceBarSetting;
	PROPERTYTYPE(DistanceBarSetting,DistanceBarSettingType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  CamraOvrlTow_D_Rq;
	PROPERTYTYPE(CamraOvrlTow_D_Rq,CamraOvrlTow_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  HMI_HMIMode_st;
	PROPERTYTYPE(HMI_HMIMode_st,HMI_HMIMode_stType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  Disp_LangSel_Rq;
	PROPERTYTYPE(Disp_LangSel_Rq,Disp_LangSel_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  Disp_LangSel2_Rq;
	PROPERTYTYPE(Disp_LangSel2_Rq,Disp_LangSel2_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  Disp_LangSel_St;
	PROPERTYTYPE(Disp_LangSel_St,Disp_LangSel_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  Disp_LangSel2_St;
	PROPERTYTYPE(Disp_LangSel2_St,Disp_LangSel2_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  FactoryReset_Rq;
	PROPERTYTYPE(FactoryReset_Rq,FactoryReset_RqType, BasicPropertyType<uint16_t>, uint16_t)

	/*****************************R1.1 release ****************************************************/
		/**Rx signal properties **/

	static const Property Mc_BTInCallOptions_Rq;
	PROPERTYTYPE(Mc_BTInCallOptions_Rq, Mc_BTInCallOptions_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Mc_PhMicrophoneMute_Rq;
	PROPERTYTYPE(Mc_PhMicrophoneMute_Rq, Mc_PhMicrophoneMute_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Veh_V_ActlEng;
	PROPERTYTYPE(Veh_V_ActlEng, Veh_V_ActlEngType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property WhlRotatFl_No_Cnt;
	PROPERTYTYPE(WhlRotatFl_No_Cnt, WhlRotatFl_No_CntType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property WhlRotatFr_No_Cnt;
	PROPERTYTYPE(WhlRotatFr_No_Cnt, WhlRotatFr_No_CntType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property WhlRotatRl_No_Cnt;
	PROPERTYTYPE(WhlRotatRl_No_Cnt, WhlRotatRl_No_CntType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property WhlRotatRr_No_Cnt;
	PROPERTYTYPE(WhlRotatRr_No_Cnt, WhlRotatRr_No_CntType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property EmgcyCallMute_D_Stat;
	PROPERTYTYPE(EmgcyCallMute_D_Stat, EmgcyCallMute_D_StatType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property EmgcyCallHmi_D_Stat;
	PROPERTYTYPE(EmgcyCallHmi_D_Stat, EmgcyCallHmi_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property EmgcyCallCancl_T_Actl;
	PROPERTYTYPE(EmgcyCallCancl_T_Actl, EmgcyCallCancl_T_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property EmgcyCall_D_Stat;
	PROPERTYTYPE(EmgcyCall_D_Stat, EmgcyCall_D_StatType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property ApaMde_D_Stat;
	PROPERTYTYPE(ApaMde_D_Stat, ApaMde_D_StatType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  Ipc_Status;
	PROPERTYTYPE(Ipc_Status,Ipc_StatusType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  TPRequest;
	//PROPERTYTYPE(TPRequest,TPRequestType, ListPropertyType<BasicPropertyType<uint16_t> >, uint16_t)
    PROPERTYTYPE(TPRequest,TPRequestType, BasicPropertyType<uintptr_t>, uintptr_t)

	static const Property  TPResponse;
	PROPERTYTYPE(TPResponse,TPResponseType, BasicPropertyType<uintptr_t>, uintptr_t)

	static const Property  EOLRequest;
	PROPERTYTYPE(EOLRequest,EOLRequestType, ListPropertyType<BasicPropertyType<uint16_t> >, uint16_t)

	static const Property  EOLResponse;
	//PROPERTYTYPE(EOLResponse,EOLResponsesType, ListPropertyType<BasicPropertyType<uint16_t> >, uint16_t)
	PROPERTYTYPE(EOLResponse,EOLResponsesType, BasicPropertyType<uintptr_t> , uintptr_t)

	static const Property  DIDRequest;
	PROPERTYTYPE(DIDRequest,DIDRequestType, BasicPropertyType<uintptr_t> , uintptr_t)

	static const Property  DIDResponse;
	PROPERTYTYPE(DIDResponse,DIDResponseType, BasicPropertyType<uintptr_t>, uintptr_t)

	static const Property  MiscRequest;
	PROPERTYTYPE(MiscRequest,MiscRequestType, BasicPropertyType<uintptr_t>, uintptr_t)

	static const Property  MiscResponse;
	PROPERTYTYPE(MiscResponse,MiscResponseType, BasicPropertyType<uintptr_t>, uintptr_t)

	static const Property  TPTransmStatus;
	PROPERTYTYPE(TPTransmStatus,TPTransmStatusType, BasicPropertyType<uintptr_t>, uintptr_t)

	static const Property  EFP_Button_Press;
	PROPERTYTYPE(EFP_Button_Press,EFP_Button_PressType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  HEC_DispDimm;
	PROPERTYTYPE(HEC_DispDimm,HEC_DispDimmType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  HUD_Send_Signals_2;
	PROPERTYTYPE(HUD_Send_Signals_2,HUD_Send_Signals_2Type, BasicPropertyType<uint32_t>, uint32_t)



	/**Tx signal properties **/
	static const Property ACU_ARAudioSource_Rsp;
	PROPERTYTYPE(ACU_ARAudioSource_Rsp, ACU_ARAudioSource_RspType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ACU_AROperationType_Rsp;
	PROPERTYTYPE(ACU_AROperationType_Rsp, ACU_AROperationType_RspType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ACU_ARReqstrSystem_Rsp;
	PROPERTYTYPE(ACU_ARReqstrSystem_Rsp, ACU_ARReqstrSystem_RspType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ACU_ARReqstrPriority_Rp;
	PROPERTYTYPE(ACU_ARReqstrPriority_Rp, ACU_ARReqstrPriority_RpType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ACU_ARResponse_Rsp;
	PROPERTYTYPE(ACU_ARResponse_Rsp, ACU_ARResponse_RspType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property VRM_BTEndTelService_Rsp;
	PROPERTYTYPE(VRM_BTEndTelService_Rsp, VRM_BTEndTelService_RspType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property BTInCallOptions_St;
	PROPERTYTYPE(BTInCallOptions_St, BTInCallOptions_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property VRM_BTIncomingCall_Rsp;
	PROPERTYTYPE(VRM_BTIncomingCall_Rsp, VRM_BTIncomingCall_RspType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property VRM_BlutoothStatus_St;
	PROPERTYTYPE(VRM_BlutoothStatus_St, VRM_BlutoothStatus_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property VRM_BTBatteryLevel_St;
	PROPERTYTYPE(VRM_BTBatteryLevel_St, VRM_BTBatteryLevel_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property VRM_BTPhoneSts_St;
	PROPERTYTYPE(VRM_BTPhoneSts_St, VRM_BTPhoneSts_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property VRM_BTNetworkStatus_St;
	PROPERTYTYPE(VRM_BTNetworkStatus_St, VRM_BTNetworkStatus_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property VRM_BTSignalStrength_St;
	PROPERTYTYPE(VRM_BTSignalStrength_St, VRM_BTSignalStrength_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property VRM_CallDuration_St;
	PROPERTYTYPE(VRM_CallDuration_St, VRM_CallDuration_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property APIM_ActiveTrackNum_St;
	PROPERTYTYPE(APIM_ActiveTrackNum_St, APIM_ActiveTrackNum_StType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property APIM_NumberofTracks_St;
	PROPERTYTYPE(APIM_NumberofTracks_St, APIM_NumberofTracks_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property AHU_Chime_Supported;
	PROPERTYTYPE(AHU_Chime_Supported, AHU_Chime_SupportedType, BasicPropertyType<uint16_t>, uint16_t)


	/******************* R1.2_new Rx Signal Support *****************************************************/
	static const Property FuelLvl_Pc_DsplyEng;
	PROPERTYTYPE(FuelLvl_Pc_DsplyEng, FuelLvl_Pc_DsplyEngType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property LangUpdate_Rsp;
	PROPERTYTYPE(LangUpdate_Rsp, LangUpdate_RspType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property SteWhlCompAnEst_D_Qf;
	PROPERTYTYPE(SteWhlCompAnEst_D_Qf, SteWhlCompAnEst_D_QfType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property VehYaw_W_Actl;
	PROPERTYTYPE(VehYaw_W_Actl, VehYaw_W_ActlType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Outside_Air_Temp_Stat;
	PROPERTYTYPE(Outside_Air_Temp_Stat, Outside_Air_Temp_StatType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  EngOil_Te_Actl;
	PROPERTYTYPE(EngOil_Te_Actl, EngOil_Te_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  EngOil_P_Actl;
	PROPERTYTYPE(EngOil_P_Actl, EngOil_P_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  EngClnt_Te_Actl;
	PROPERTYTYPE(EngClnt_Te_Actl, EngClnt_Te_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  GboxOil_Te_Actl;
	PROPERTYTYPE(GboxOil_Te_Actl, GboxOil_Te_ActlType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  TrnIpcDsplyGear_D_Actl;
	PROPERTYTYPE(TrnIpcDsplyGear_D_Actl, TrnIpcDsplyGear_D_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  AbsActv_B_Actl;
	PROPERTYTYPE(AbsActv_B_Actl, AbsActv_B_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  FuelFlw_Vl_ActlFoh;
	PROPERTYTYPE(FuelFlw_Vl_ActlFoh, FuelFlw_Vl_ActlFohType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  RearDiffOil_Te_Actl;
	PROPERTYTYPE(RearDiffOil_Te_Actl, RearDiffOil_Te_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  DrStatPsngr_B_Actl;
	PROPERTYTYPE(DrStatPsngr_B_Actl, DrStatPsngr_B_ActlType, BasicPropertyType<uint16_t>, uint16_t)


	static const Property DrStatRl_B_Actl;
	PROPERTYTYPE(DrStatRl_B_Actl, DrStatRl_B_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property DrStatRr_B_Actl;
	PROPERTYTYPE(DrStatRr_B_Actl, DrStatRr_B_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property  IPC_Chime;
	PROPERTYTYPE(IPC_Chime,IPC_ChimeType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  IPC_Chime2;
	PROPERTYTYPE(IPC_Chime2,IPC_Chime2Type, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  Tire_Pressure_Status;
	PROPERTYTYPE(Tire_Pressure_Status,Tire_Pressure_StatusType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  Tire_Pressure_Data_HS3;
	PROPERTYTYPE(Tire_Pressure_Data_HS3,Tire_Pressure_Data_HS3Type, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  Tire_Pressure_Data_DRW_HS3;
	PROPERTYTYPE(Tire_Pressure_Data_DRW_HS3,Tire_Pressure_Data_DRW_HS3Type, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  VehEmergencyData1_HS3;
	PROPERTYTYPE(VehEmergencyData1_HS3,VehEmergencyData1_HS3Type, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  VehEmergencyData2_HS3;
	PROPERTYTYPE(VehEmergencyData2_HS3,VehEmergencyData2_HS3Type, BasicPropertyType<uint32_t>, uint32_t)

	static const Property  ParkAid_Data_HS3;
	PROPERTYTYPE(ParkAid_Data_HS3,ParkAid_Data_HS3Type, BasicPropertyType<uint32_t>, uint32_t)

	/************************************************************************************************/

	/***************************************Rx 14Nov********************************************************/
	static const Property PrkAidMsgTxt_D_Rq;
	PROPERTYTYPE(PrkAidMsgTxt_D_Rq,PrkAidMsgTxt_D_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property PrkAidSnsRlCrnr_D_Stat;
	PROPERTYTYPE(PrkAidSnsRlCrnr_D_Stat, PrkAidSnsRlCrnr_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property PrkAidSnsRlCntr_D_Stat;
	PROPERTYTYPE(PrkAidSnsRlCntr_D_Stat, PrkAidSnsRlCntr_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property PrkAidSnsRrCntr_D_Stat;
	PROPERTYTYPE(PrkAidSnsRrCntr_D_Stat, PrkAidSnsRrCntr_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property PrkAidSnsRrCrnr_D_Stat;
	PROPERTYTYPE(PrkAidSnsRrCrnr_D_Stat, PrkAidSnsRrCrnr_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property PrkAidSnsFlCrnr_D_Stat;
	PROPERTYTYPE(PrkAidSnsFlCrnr_D_Stat, PrkAidSnsFlCrnr_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property PrkAidSnsFlCntr_D_Stat;
	PROPERTYTYPE(PrkAidSnsFlCntr_D_Stat, PrkAidSnsFlCntr_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property PrkAidSnsFrCrnr_D_Stat;
	PROPERTYTYPE(PrkAidSnsFrCrnr_D_Stat, PrkAidSnsFrCrnr_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property SidePrkSnsL1_D_Stat;
	PROPERTYTYPE(SidePrkSnsL1_D_Stat, SidePrkSnsL1_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property PrkAidSnsFrCntr_D_Stat;
	PROPERTYTYPE(PrkAidSnsFrCntr_D_Stat, PrkAidSnsFrCntr_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	/************************************************************************************************/

	/***********************************Rx 16 Nov2106*************************************************************/
	static const Property SidePrkSnsR1_D_Stat;
	PROPERTYTYPE(SidePrkSnsR1_D_Stat, SidePrkSnsR1_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property SidePrkSnsL2_D_Stat;
	PROPERTYTYPE(SidePrkSnsL2_D_Stat, SidePrkSnsL2_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property SidePrkSnsR2_D_Stat;
	PROPERTYTYPE(SidePrkSnsR2_D_Stat, SidePrkSnsR2_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property SidePrkSnsL3_D_Stat;
	PROPERTYTYPE(SidePrkSnsL3_D_Stat, SidePrkSnsL3_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property SidePrkSnsR3_D_Stat;
	PROPERTYTYPE(SidePrkSnsR3_D_Stat, SidePrkSnsR3_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property SidePrkSnsL4_D_Stat;
	PROPERTYTYPE(SidePrkSnsL4_D_Stat, SidePrkSnsL4_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property SidePrkSnsR4_D_Stat;
	PROPERTYTYPE(SidePrkSnsR4_D_Stat, SidePrkSnsR4_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	/************************************************************************************************/

	/***********************************Rx 22 Nov2106*************************************************************/
	static const Property Clmt_Button_Stat1_HS3;
	PROPERTYTYPE(Clmt_Button_Stat1_HS3, Clmt_Button_Stat1_HS3Type, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Clmt_Button_Stat2_HS3;
	PROPERTYTYPE(Clmt_Button_Stat2_HS3, Clmt_Button_Stat2_HS3Type, BasicPropertyType<uint32_t>, uint32_t)

	static const Property FactoryReset_St;
	PROPERTYTYPE(FactoryReset_St, FactoryReset_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property TrnAin_Tq_Actl;
	PROPERTYTYPE(TrnAin_Tq_Actl, TrnAin_Tq_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property FuelFlw_Vl_Dsply;
	PROPERTYTYPE(FuelFlw_Vl_Dsply, FuelFlw_Vl_DsplyType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property OdometerMasterValue;
	PROPERTYTYPE(OdometerMasterValue, OdometerMasterValueType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property HeadLghtHiOn_B_Stat;
	PROPERTYTYPE(HeadLghtHiOn_B_Stat, HeadLghtHiOn_B_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property HeadLampLoActv_B_Stat;
	PROPERTYTYPE(HeadLampLoActv_B_Stat, HeadLampLoActv_B_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property WiprFront_D_Stat;
	PROPERTYTYPE(WiprFront_D_Stat, WiprFront_D_StatType, BasicPropertyType<uint32_t>, uint32_t)

	/************************************************************************************************/

	/***********************************Rx 1 Dec 2106*************************************************************/

		static const Property EFP2_Button_Press;
		PROPERTYTYPE(EFP2_Button_Press, EFP2_Button_PressType, BasicPropertyType<uint32_t>, uint32_t)

		static const Property ACU_Send_Signals_5;
		PROPERTYTYPE(ACU_Send_Signals_5, ACU_Send_Signals_5Type, BasicPropertyType<uint32_t>, uint32_t)

		static const Property TCU_Sftwr_Update_D_St;
		PROPERTYTYPE(TCU_Sftwr_Update_D_St, TCU_Sftwr_Update_D_StType, BasicPropertyType<uint16_t>, uint16_t)

		static const Property TelematicsSrvc_D_St;
		PROPERTYTYPE(TelematicsSrvc_D_St, TelematicsSrvc_D_StType, BasicPropertyType<uint16_t>, uint16_t)

		static const Property TCU_Request_Signals_2;
		PROPERTYTYPE(TCU_Request_Signals_2, TCU_Request_Signals_2Type, BasicPropertyType<uint32_t>, uint32_t)

		static const Property MC_Send_Signals_1;
		PROPERTYTYPE(MC_Send_Signals_1, MC_Send_Signals_1Type, BasicPropertyType<uint32_t>, uint32_t)

		static const Property IgnKeyType_D_Actl;
		PROPERTYTYPE(IgnKeyType_D_Actl, IgnKeyType_D_ActlType, BasicPropertyType<uint16_t>, uint16_t)

		static const Property Mc_Send_Signals_3;
		PROPERTYTYPE(Mc_Send_Signals_3, Mc_Send_Signals_3Type, BasicPropertyType<uint32_t>, uint32_t)

		/*static const Property LBClient1_Request_Signals;
		PROPERTYTYPE(LBClient1_Request_Signals, LBClient1_Request_SignalsType, ListPropertyType<BasicPropertyType<uint16_t> >, uint16_t)*/

		static const Property LBClient1_Request_Signals;
		PROPERTYTYPE(LBClient1_Request_Signals, LBClient1_Request_SignalsType, BasicPropertyType<uint32_t>, uint32_t)


		static const Property CD_Request_Signals;
		PROPERTYTYPE(CD_Request_Signals, CD_Request_SignalsType, BasicPropertyType<uint32_t>, uint32_t)

		static const Property TCU_Send_Signals_3;
		PROPERTYTYPE(TCU_Send_Signals_3, TCU_Send_Signals_3Type, BasicPropertyType<uint32_t>, uint32_t)

	/************************************************************************************************/

  /*******************  R1.2 Tx Signal Support *****************************************************/

	static const Property ACU_RUAudioSource_St;
	PROPERTYTYPE(ACU_RUAudioSource_St, ACU_RUAudioSource_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ACU_RUReqstrSystem_St;
	PROPERTYTYPE(ACU_RUReqstrSystem_St, ACU_RUReqstrSystem_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ACU_RUResReqstStatus_St;
	PROPERTYTYPE(ACU_RUResReqstStatus_St, ACU_RUResReqstStatus_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ACU_RUReqstrPriority_St;
	PROPERTYTYPE(ACU_RUReqstrPriority_St, ACU_RUReqstrPriority_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property EmgcyAsstActv_D_Stat;
	PROPERTYTYPE(EmgcyAsstActv_D_Stat, EmgcyAsstActv_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property LocationServices_1;
	PROPERTYTYPE(LocationServices_1, LocationServices_1Type, BasicPropertyType<uint64_t>, uint64_t)

	static const Property LightAmbColor_No_Rq;
	PROPERTYTYPE(LightAmbColor_No_Rq, LightAmbColor_No_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property LightAmbIntsty_No_Rq;
	PROPERTYTYPE(LightAmbIntsty_No_Rq, LightAmbIntsty_No_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property SetTimeFormat;
	PROPERTYTYPE(SetTimeFormat, SetTimeFormatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Disp_VehUnitTempUsrSel;
	PROPERTYTYPE(Disp_VehUnitTempUsrSel, Disp_VehUnitTempUsrSelType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Disp_VehUntTripCoUsrSel;
	PROPERTYTYPE(Disp_VehUntTripCoUsrSel, Disp_VehUntTripCoUsrSelType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property CDWarnChime_Rq;
	PROPERTYTYPE(CDWarnChime_Rq, CDWarnChime_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property CDWarnChime_St;
	PROPERTYTYPE(CDWarnChime_St, CDWarnChime_StType, BasicPropertyType<uint16_t>, uint16_t)

	/************************************************************************/

	/**********************Tx 16 Nov2016**************************************************/
	static const Property DISP_SetVolume_Rq;
	PROPERTYTYPE(DISP_SetVolume_Rq, DISP_SetVolume_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property SpkrStdRight_D_Stat;
	PROPERTYTYPE(SpkrStdRight_D_Stat, SpkrStdRight_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property SpkrStdLeft_D_Stat;
	PROPERTYTYPE(SpkrStdLeft_D_Stat, SpkrStdLeft_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property SpkrStdCntr_D_Stat;
	PROPERTYTYPE(SpkrStdCntr_D_Stat, SpkrStdCntr_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Voice_Blower_Limit;
	PROPERTYTYPE(Voice_Blower_Limit, Voice_Blower_LimitType, BasicPropertyType<uint16_t>, uint16_t)

	/************************************************************************/

	/**********************Tx 1Dec2016**************************************************/

		static const Property ACU_CurrentFreq_St;
		PROPERTYTYPE(ACU_CurrentFreq_St, ACU_CurrentFreq_StType, BasicPropertyType<uint16_t>, uint16_t)

		static const Property TCU_ESN_D_Rq;
		PROPERTYTYPE(TCU_ESN_D_Rq, TCU_ESN_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

		static const Property TCU_Final_Actvtn_St;
		PROPERTYTYPE(TCU_Final_Actvtn_St, TCU_Final_Actvtn_StType, BasicPropertyType<uint16_t>, uint16_t)

		static const Property TCU_Init_Actvtn_St;
		PROPERTYTYPE(TCU_Init_Actvtn_St, TCU_Init_Actvtn_StType, BasicPropertyType<uint16_t>, uint16_t)

	/************************************************************************/

	/*******************  R1.2 Rx Signal Support *****************************************************/
	static const Property VehVActlEng_D_Qf;
	PROPERTYTYPE(VehVActlEng_D_Qf, VehVActlEng_D_QfType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property GearRvrse_D_Actl;
	PROPERTYTYPE(GearRvrse_D_Actl, GearRvrse_D_ActlType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property LightAmbColor_No_Actl;
	PROPERTYTYPE(LightAmbColor_No_Actl, LightAmbColor_No_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property LightAmbIntsty_No_Actl;
	PROPERTYTYPE(LightAmbIntsty_No_Actl, LightAmbIntsty_No_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property OdoCount;
	PROPERTYTYPE(OdoCount, OdoCountType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Mc_VehUntTrpCoUsrSel_St;
	PROPERTYTYPE(Mc_VehUntTrpCoUsrSel_St, Mc_VehUntTrpCoUsrSel_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Mc_VehTimeFrmtUsrSel_St;
	PROPERTYTYPE(Mc_VehTimeFrmtUsrSel_St, Mc_VehTimeFrmtUsrSel_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Mc_VehUnitTempUsrSel_St;
	PROPERTYTYPE(Mc_VehUnitTempUsrSel_St, Mc_VehUnitTempUsrSel_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property VehicleGGCCData;
	PROPERTYTYPE(VehicleGGCCData, VehicleGGCCDataType, BasicPropertyType<uint64_t>, uint64_t)

	static const Property WrlssAcsyChrgr_D_Stat;
	PROPERTYTYPE(WrlssAcsyChrgr_D_Stat, WrlssAcsyChrgr_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property McLangSel2_Rq;
	PROPERTYTYPE(McLangSel2_Rq, McLangSel2_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Mc_LangSel_Rq;
	PROPERTYTYPE(Mc_LangSel_Rq, Mc_LangSel_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Mc_VehLangUsrSel_St;
	PROPERTYTYPE(Mc_VehLangUsrSel_St, Mc_VehLangUsrSel_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Dsp_LangUpdate_Rsp;
	PROPERTYTYPE(Dsp_LangUpdate_Rsp, Dsp_LangUpdate_RspType, BasicPropertyType<uint16_t>, uint16_t)


	static const Property LBS1_ListStatus;
	PROPERTYTYPE(LBS1_ListStatus, LBS1_ListStatusType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property LBS1_EntryIndex;
	PROPERTYTYPE(LBS1_EntryIndex, LBS1_EntryIndexType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property LBS1_ParentID;
	PROPERTYTYPE(LBS1_ParentID, LBS1_ParentIDType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property LBS1_ListID;
	PROPERTYTYPE(LBS1_ListID, LBS1_ListIDType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property LBS1_ListServer;
	PROPERTYTYPE(LBS1_ListServer, LBS1_ListServerType, BasicPropertyType<uint16_t>, uint16_t)


	static const Property WifiCarrierInfo_B_Rq;
	PROPERTYTYPE(WifiCarrierInfo_B_Rq, WifiCarrierInfo_B_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property WifiDataUsage_D_Rq;
	PROPERTYTYPE(WifiDataUsage_D_Rq, WifiDataUsage_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property WifiDevcList_D_Rq;
	PROPERTYTYPE(WifiDevcList_D_Rq, WifiDevcList_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property WifiDevcListIndx_No_Rq;
	PROPERTYTYPE(WifiDevcListIndx_No_Rq, WifiDevcListIndx_No_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property WifiDevcListSize_D_Rq;
	PROPERTYTYPE(WifiDevcListSize_D_Rq, WifiDevcListSize_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property WifiHtsptEnbl_D_Rq;
	PROPERTYTYPE(WifiHtsptEnbl_D_Rq, WifiHtsptEnbl_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property WifiHtsptMacAddr_B_Rq;
	PROPERTYTYPE(WifiHtsptMacAddr_B_Rq, WifiHtsptMacAddr_B_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property WifiHtsptTrial_D_RqDrv;
	PROPERTYTYPE(WifiHtsptTrial_D_RqDrv, WifiHtsptTrial_D_RqDrvType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property WifiHtsptVisbl_D_Rq;
	PROPERTYTYPE(WifiHtsptVisbl_D_Rq, WifiHtsptVisbl_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property WifiRemoveDevc_D_Rq;
	PROPERTYTYPE(WifiRemoveDevc_D_Rq, WifiRemoveDevc_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property WifiRemoveIndx_No_Rq;
	PROPERTYTYPE(WifiRemoveIndx_No_Rq, WifiRemoveIndx_No_RqType, BasicPropertyType<uint16_t>, uint16_t)
	/************************************************************************/

	/*******************SRCSINGLEPLUGINCHANGES  R1.1 Tx Signal Support *****************************************************/
	//NOt needed

	static const Property HdcOn_B_Rq;
	PROPERTYTYPE(HdcOn_B_Rq, HdcOn_B_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property HudVertSzMnuOn_B_Rq;
	PROPERTYTYPE(HudVertSzMnuOn_B_Rq, HudVertSzMnuOn_B_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property HudCntntMnuOn_B_Rq;
	PROPERTYTYPE(HudCntntMnuOn_B_Rq, HudCntntMnuOn_B_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Veh_V2_Dsply;
	PROPERTYTYPE(Veh_V2_Dsply, Veh_V2_DsplyType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property HudVertMnuOn_B_Rq;
	PROPERTYTYPE(HudVertMnuOn_B_Rq, HudVertMnuOn_B_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property HudRotatMnuOn_B_Rq;
	PROPERTYTYPE(HudRotatMnuOn_B_Rq, HudRotatMnuOn_B_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property HudHzntlMnuOn_B_Rq;
	PROPERTYTYPE(HudHzntlMnuOn_B_Rq, HudHzntlMnuOn_B_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property HudBrightMnuOn_B_Rq;
	PROPERTYTYPE(HudBrightMnuOn_B_Rq, HudBrightMnuOn_B_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property MetricActv_B_Dsply;
	PROPERTYTYPE(MetricActv_B_Dsply, MetricActv_B_DsplyType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Veh_V_Dsply;
	PROPERTYTYPE(Veh_V_Dsply, Veh_V_DsplyType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property DrvPerfMde_D_DsplyHud;
	PROPERTYTYPE(DrvPerfMde_D_DsplyHud, DrvPerfMde_D_DsplyHudType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property IPC_MyKeyVolLimit_St;
	PROPERTYTYPE(IPC_MyKeyVolLimit_St, IPC_MyKeyVolLimit_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property BeltminderAudioMute;
	PROPERTYTYPE(BeltminderAudioMute, BeltminderAudioMuteType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property IPC_New_Attn_Event;
	PROPERTYTYPE(IPC_New_Attn_Event, IPC_New_Attn_EventType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property IPC_Attn_Info_Audio;
	PROPERTYTYPE(IPC_Attn_Info_Audio, IPC_Attn_Info_AudioType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Power_Up_Chime_Modules;
	PROPERTYTYPE(Power_Up_Chime_Modules, Power_Up_Chime_ModulesType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Chime_Source;
	PROPERTYTYPE(Chime_Source, Chime_SourceType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ApaMdeStat_D_RqDrv;
	PROPERTYTYPE(ApaMdeStat_D_RqDrv, ApaMdeStat_D_RqDrvType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property FuelLvl_Pc_Dsply;
	PROPERTYTYPE(FuelLvl_Pc_Dsply, FuelLvl_Pc_DsplyType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property EngAoutTqActl_D_Qf;
	PROPERTYTYPE(EngAoutTqActl_D_Qf, EngAoutTqActl_D_QfType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property CamraViewSplit_B_Rq;
	PROPERTYTYPE(CamraViewSplit_B_Rq, CamraViewSplit_B_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property StabCtlBrkActv_B_Actl;
	PROPERTYTYPE(StabCtlBrkActv_B_Actl, StabCtlBrkActv_B_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property TCMode;
	PROPERTYTYPE(TCMode, TCModeType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property EngMnfld_P_Actl;
	PROPERTYTYPE(EngMnfld_P_Actl, EngMnfld_P_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property KeyOffMde_D_Actl;
	PROPERTYTYPE(KeyOffMde_D_Actl, KeyOffMde_D_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property PrkAidDrvDir_D_Stat;
	PROPERTYTYPE(PrkAidDrvDir_D_Stat, PrkAidDrvDir_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property CCOI_PolicyClient_St;
	PROPERTYTYPE(CCOI_PolicyClient_St, CCOI_PolicyClient_StType, BasicPropertyType<uint16_t>, uint16_t)
	/*****************************DTCPlugin****************************************************/
		static const Property SetDTCRequest;
		PROPERTYTYPE(SetDTCRequest,SetDTCRequest_Type, BasicPropertyType<uintptr_t>, uintptr_t)

		static const Property SetDTCResponse;
		PROPERTYTYPE(SetDTCResponse,SetDTCResponse_Type, BasicPropertyType<uintptr_t>, uintptr_t)

        static const Property ClearDTCRequest;
		PROPERTYTYPE(ClearDTCRequest,ClearDTCRequest_Type, BasicPropertyType<uintptr_t>, uintptr_t)

        static const Property ClearDTCResponse;
		PROPERTYTYPE(ClearDTCResponse,ClearDTCResponse_Type, BasicPropertyType<uintptr_t>, uintptr_t)

        static const Property ReadDTCRequest;
		PROPERTYTYPE(ReadDTCRequest,ReadDTCRequest_Type, BasicPropertyType<uintptr_t>, uintptr_t)

        static const Property ReadDTCResponse;
		PROPERTYTYPE(ReadDTCResponse,ReadDTCResponse_Type, BasicPropertyType<uintptr_t>, uintptr_t)

        static const Property AllDTCClearStat;
		PROPERTYTYPE(AllDTCClearStat,AllDTCClearStat_Type, BasicPropertyType<uintptr_t>, uintptr_t)

		static const Property ReadDIDRequest;
		PROPERTYTYPE(ReadDIDRequest,ReadDIDRequest_Type, BasicPropertyType<uintptr_t>, uintptr_t)

		static const Property ReadDIDResponse;
        PROPERTYTYPE(ReadDIDResponse,ReadDIDResponse_Type, BasicPropertyType<uintptr_t>, uintptr_t)

		static const Property GenericReadDataReq;
        PROPERTYTYPE(GenericReadDataReq,GenericReadDataReq_Type, BasicPropertyType<uintptr_t>, uintptr_t)

		static const Property GenericReadDataResp;
        PROPERTYTYPE(GenericReadDataResp,GenericReadDataResp_Type, BasicPropertyType<uintptr_t>, uintptr_t)

        static const Property SetEolDataReq;
        PROPERTYTYPE(SetEolDataReq,SetEolDataReq_Type, BasicPropertyType<uintptr_t>, uintptr_t)

        static const Property SetEolDataResp;
        PROPERTYTYPE(SetEolDataResp,SetEolDataResp_Type, BasicPropertyType<uintptr_t>, uintptr_t)

	/******************************* GPS data *******************************************/
		static const Property GPS_RxData;
		PROPERTYTYPE(GPS_RxData, GPS_RxDataType, BasicPropertyType<uint64_t>, uint64_t)

		static const Property GPS_TxData;
		PROPERTYTYPE(GPS_TxData, GPS_TxDataType, BasicPropertyType<uintptr_t>, uintptr_t)

	/************************************TimeOut Properties************************************/
	static const Property PrkBrkActv_B_Actl;
	PROPERTYTYPE(PrkBrkActv_B_Actl, PrkBrkActv_B_ActlType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property PrkBrkStatus;
	PROPERTYTYPE(PrkBrkStatus, PrkBrkStatusType, BasicPropertyType<uint32_t>, uint32_t)

	/*******************************************************************************************/

	/*****************************************UB Properties**************************************/
	static const Property CamPDCGuidStat;
	PROPERTYTYPE(CamPDCGuidStat, CamPDCGuidStatType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property CamraOvrlDyn_D_Actl;
	PROPERTYTYPE(CamraOvrlDyn_D_Actl, CamraOvrlDyn_D_ActlType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property CamraZoomMan_D_Actl;
	PROPERTYTYPE(CamraZoomMan_D_Actl, CamraZoomMan_D_ActlType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property CamZoomActiveState;
	PROPERTYTYPE(CamZoomActiveState, CamZoomActiveStateType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property CCOI_PolicyServer_St;
	PROPERTYTYPE(CCOI_PolicyServer_St, CCOI_PolicyServer_StType, BasicPropertyType<uint32_t>, uint32_t)


	static const Property GearLvrPos_D_Actl;
	PROPERTYTYPE(GearLvrPos_D_Actl, GearLvrPos_D_ActlType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property PtDrvMde_D_Stat;
	PROPERTYTYPE(PtDrvMde_D_Stat, PtDrvMde_D_StatType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property PwPck_D_Stat;
	PROPERTYTYPE(PwPck_D_Stat, PwPck_D_StatType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property VehLong2_A_Actl;
	PROPERTYTYPE(VehLong2_A_Actl, VehLong2_A_ActlType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property BpedDrvAppl_D_Actl;
	PROPERTYTYPE(BpedDrvAppl_D_Actl, BpedDrvAppl_D_ActlType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property BSBattSOC;
    PROPERTYTYPE(BSBattSOC, BSBattSOCType, BasicPropertyType<uint32_t>, uint32_t)

    static const Property CamraViewSplit_D_Actl;
    PROPERTYTYPE(CamraViewSplit_D_Actl, CamraViewSplit_D_ActlType, BasicPropertyType<uint32_t>, uint32_t)

    static const Property VehOverGnd_V_Est;
    PROPERTYTYPE(VehOverGnd_V_Est, VehOverGnd_V_EstType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property VehPtch_An_Dsply;
    PROPERTYTYPE(VehPtch_An_Dsply, VehPtch_An_DsplyType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property VehRol_An_Dsply;
    PROPERTYTYPE(VehRol_An_Dsply, VehRol_An_DsplyType, BasicPropertyType<uint32_t>, uint32_t)

	/********************************************************************************************/
    /**********************************  R2.0.2  ************************************************/
	static const Property DriverWindowPosition;
	PROPERTYTYPE(DriverWindowPosition, DriverWindowPositionType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property PassWindowPosition;
	PROPERTYTYPE(PassWindowPosition, PassWindowPositionType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property RearDriverWindowPos;
	PROPERTYTYPE(RearDriverWindowPos, RearDriverWindowPosType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property RearPassWindowPos;
	PROPERTYTYPE(RearPassWindowPos, RearPassWindowPosType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property TurnLghtSwtch_D_Stat;
	PROPERTYTYPE(TurnLghtSwtch_D_Stat, TurnLghtSwtch_D_StatType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property BrkTot_Tq_RqArb;
	PROPERTYTYPE(BrkTot_Tq_RqArb, BrkTot_Tq_RqArbType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property DoNotDisturbOverride_St;
	PROPERTYTYPE(DoNotDisturbOverride_St, DoNotDisturbOverride_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property PrkAidRdiusLeft_L_Dsply;
	PROPERTYTYPE(PrkAidRdiusLeft_L_Dsply, PrkAidRdiusLeft_L_DsplyType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property PrkAidRdiusRight_L_Dsply;
	PROPERTYTYPE(PrkAidRdiusRight_L_Dsply, PrkAidRdiusRight_L_DsplyType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property PwPckTq_D_Stat;
	PROPERTYTYPE(PwPckTq_D_Stat, PwPckTq_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ApedPosPcActl_D_Qf;
	PROPERTYTYPE(ApedPosPcActl_D_Qf, ApedPosPcActl_D_QfType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ActvDrvMde_D2_Stat;
	PROPERTYTYPE(ActvDrvMde_D2_Stat, ActvDrvMde_D2_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property EngExhMdeQuiet_D_Stat;
	PROPERTYTYPE(EngExhMdeQuiet_D_Stat, EngExhMdeQuiet_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property TrnAinTq_D_Qf;
	PROPERTYTYPE(TrnAinTq_D_Qf, TrnAinTq_D_QfType, BasicPropertyType<uint16_t>, uint16_t)

	//Tx
	static const Property ACU_CurrTUBand_St;
	PROPERTYTYPE(ACU_CurrTUBand_St, ACU_CurrTUBand_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ACU_RadioSeekMode2_St;
	PROPERTYTYPE(ACU_RadioSeekMode2_St, ACU_RadioSeekMode2_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property AHU_Chime2_Active;
	PROPERTYTYPE(AHU_Chime2_Active, AHU_Chime2_ActiveType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property AHU_Chime2_Not_Recgnizd;
	PROPERTYTYPE(AHU_Chime2_Not_Recgnizd, AHU_Chime2_Not_RecgnizdType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property AHU_Chime_Active;
	PROPERTYTYPE(AHU_Chime_Active, AHU_Chime_ActiveType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property AHU_Chime_Not_Recgnizd;
	PROPERTYTYPE(AHU_Chime_Not_Recgnizd, AHU_Chime_Not_RecgnizdType, BasicPropertyType<uint16_t>, uint16_t)

	/**************** R2.0.2a ************************************************/
	static const Property GPS_Compass_direction;
	PROPERTYTYPE(GPS_Compass_direction, GPS_Compass_directionType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property FuelLvlWarn_D_ActlEng;
	PROPERTYTYPE(FuelLvlWarn_D_ActlEng, FuelLvlWarn_D_ActlEngType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property FuelRange_L_Dsply;
	PROPERTYTYPE(FuelRange_L_Dsply, FuelRange_L_DsplyType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property KeyMykeyTot_No_Cnt;
	PROPERTYTYPE(KeyMykeyTot_No_Cnt, KeyMykeyTot_No_CntType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property TrnAout_W_ActlUnfilt;
	PROPERTYTYPE(TrnAout_W_ActlUnfilt, TrnAout_W_ActlUnfiltType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ApaBrk_A_Rq;
	PROPERTYTYPE(ApaBrk_A_Rq, ApaBrk_A_RqType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property Parklamp_Status;
	PROPERTYTYPE(Parklamp_Status, Parklamp_StatusType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ACU_CurrPreset2_St;
	PROPERTYTYPE(ACU_CurrPreset2_St, ACU_CurrPreset2_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ACU_ActServiceLink_St;
	PROPERTYTYPE(ACU_ActServiceLink_St, ACU_ActServiceLink_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ACU_CurrTUDRService2_St;
	PROPERTYTYPE(ACU_CurrTUDRService2_St, ACU_CurrTUDRService2_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ACU_CurrTUDABBlock_St;
	PROPERTYTYPE(ACU_CurrTUDABBlock_St, ACU_CurrTUDABBlock_StType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property ACU_CurrentPSName_St;
	PROPERTYTYPE(ACU_CurrentPSName_St, ACU_CurrentPSName_StType, BasicPropertyType<uint64_t>, uint64_t)

	static const Property Veh_Lock_Status;
	PROPERTYTYPE(Veh_Lock_Status, Veh_Lock_StatusType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property AwdStat_D_RqDsply;
	PROPERTYTYPE(AwdStat_D_RqDsply, AwdStat_D_RqDsplyType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property DrStatInnrTgate_B_Actl;
	PROPERTYTYPE(DrStatInnrTgate_B_Actl, DrStatInnrTgate_B_ActlType, BasicPropertyType<uint16_t>, uint16_t)

	static const Property StePinComp_An_Est;
	PROPERTYTYPE(StePinComp_An_Est, StePinComp_An_EstType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property ACU_Send_Signals_6;
	PROPERTYTYPE(ACU_Send_Signals_6, ACU_Send_Signals_6Type, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Personality_APIM_Data2;
	PROPERTYTYPE(Personality_APIM_Data2, Personality_APIM_Data2Type, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Personality_BCM2_Data_HS3;
	PROPERTYTYPE(Personality_BCM2_Data_HS3, Personality_BCM2_Data_HS3Type, BasicPropertyType<uint32_t>, uint32_t)

	static const Property TCU_Request_Signals_1;
	PROPERTYTYPE(TCU_Request_Signals_1, TCU_Request_Signals_1Type, BasicPropertyType<uint32_t>, uint32_t)

	static const Property HMI_SetCompression_Rq;
	PROPERTYTYPE(HMI_SetCompression_Rq, HMI_SetCompression_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property NAV_CDSetIntroScan_Rq;
	PROPERTYTYPE(NAV_CDSetIntroScan_Rq, NAV_CDSetIntroScan_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property HMI_SkipTrack_Rq;
	PROPERTYTYPE(HMI_SkipTrack_Rq, HMI_SkipTrack_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_GetCDTOCDData_Rq;
	PROPERTYTYPE(Dsp_GetCDTOCDData_Rq, Dsp_GetCDTOCDData_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_AudioSourceSel_Rq;
	PROPERTYTYPE(Dsp_AudioSourceSel_Rq, Dsp_AudioSourceSel_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_ItemNameLength_Rq;
	PROPERTYTYPE(Dsp_ItemNameLength_Rq, Dsp_ItemNameLength_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_CutItem_Rq;
	PROPERTYTYPE(Dsp_CutItem_Rq, Dsp_CutItem_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_FolderNumber_Rq;
	PROPERTYTYPE(Dsp_FolderNumber_Rq, Dsp_FolderNumber_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_SourceSetTrack_Rq;
	PROPERTYTYPE(Dsp_SourceSetTrack_Rq, Dsp_SourceSetTrack_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property ACU_CompLogic_St;
	PROPERTYTYPE(ACU_CompLogic_St, ACU_CompLogic_StType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_StartItemIndexRq;
	PROPERTYTYPE(Dsp_StartItemIndexRq, Dsp_StartItemIndexRqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property OtaTrg_D_Stat;
	PROPERTYTYPE(OtaTrg_D_Stat, OtaTrg_D_StatType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property CD_Send_Signals;
	PROPERTYTYPE(CD_Send_Signals, CD_Send_SignalsType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property ACU_SendSignals_9;
	PROPERTYTYPE(ACU_SendSignals_9, ACU_SendSignals_9Type, BasicPropertyType<uint32_t>, uint32_t)

	static const Property NAV_CDSetRepeat_Rq;
	PROPERTYTYPE(NAV_CDSetRepeat_Rq, NAV_CDSetRepeat_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property NAV_CDSetShuffle_Rq;
	PROPERTYTYPE(NAV_CDSetShuffle_Rq, NAV_CDSetShuffle_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_FolderContent_Rq;
	PROPERTYTYPE(Dsp_FolderContent_Rq, Dsp_FolderContent_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_CutItem2_Rq;
	PROPERTYTYPE(Dsp_CutItem2_Rq, Dsp_CutItem2_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_ItemNameLength2_Rq;
	PROPERTYTYPE(Dsp_ItemNameLength2_Rq, Dsp_ItemNameLength2_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_NbrOfItems2_Rq;
	PROPERTYTYPE(Dsp_NbrOfItems2_Rq, Dsp_NbrOfItems2_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_FolderNumber2_Rq;
	PROPERTYTYPE(Dsp_FolderNumber2_Rq, Dsp_FolderNumber2_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_AudioSourceSel2_Rq;
	PROPERTYTYPE(Dsp_AudioSourceSel2_Rq, Dsp_AudioSourceSel2_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property NAV_SetOperationMode_Rq;
	PROPERTYTYPE(NAV_SetOperationMode_Rq, NAV_SetOperationMode_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property NAV_LoadEjectDisc_Rq;
	PROPERTYTYPE(NAV_LoadEjectDisc_Rq, NAV_LoadEjectDisc_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property NAV_LoadEjectMode_Rq;
	PROPERTYTYPE(NAV_LoadEjectMode_Rq, NAV_LoadEjectMode_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_FolderNumber3_Rq;
	PROPERTYTYPE(Dsp_FolderNumber3_Rq, Dsp_FolderNumber3_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_ItemIndex_Rq;
	PROPERTYTYPE(Dsp_ItemIndex_Rq, Dsp_ItemIndex_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_PlayFrstTrInFldr_Rq;
	PROPERTYTYPE(Dsp_PlayFrstTrInFldr_Rq, Dsp_PlayFrstTrInFldr_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property Dsp_AudioSourceSel3_Rq;
	PROPERTYTYPE(Dsp_AudioSourceSel3_Rq, Dsp_AudioSourceSel3_RqType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property CtaAlrtLeft_D_Stat;
	PROPERTYTYPE(CtaAlrtLeft_D_Stat, CtaAlrtLeft_D_StatType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property CtaAlrtRight_D_Stat;
	PROPERTYTYPE(CtaAlrtRight_D_Stat, CtaAlrtRight_D_StatType, BasicPropertyType<uint32_t>, uint32_t)

	static const Property CntrStkKeycodeActl;
	PROPERTYTYPE(CntrStkKeycodeActl, CntrStkKeycodeActlType, BasicPropertyType<uint32_t>, uint32_t)


	static const Property CntrStk_D_RqAssoc;
	PROPERTYTYPE(CntrStk_D_RqAssoc, CntrStk_D_RqAssocType, BasicPropertyType<uint32_t>, uint32_t)

	//Lumbar Signal Support
static const Property SeatFnDrv_D_Stat;
PROPERTYTYPE(SeatFnDrv_D_Stat, SeatFnDrv_D_StatType, BasicPropertyType<uint32_t>, uint32_t)

static const Property SeatFnPsgr_D_Stat;
PROPERTYTYPE(SeatFnPsgr_D_Stat, SeatFnPsgr_D_StatType, BasicPropertyType<uint32_t>, uint32_t)

static const Property SeatScrnDrvOn_B_Rq;
PROPERTYTYPE(SeatScrnDrvOn_B_Rq, SeatScrnDrvOn_B_RqType, BasicPropertyType<uint32_t>, uint32_t)

static const Property SeatScrnPsngrOn_B_Rq;
PROPERTYTYPE(SeatScrnPsngrOn_B_Rq, SeatScrnPsngrOn_B_RqType, BasicPropertyType<uint32_t>, uint32_t)

static const Property SeatIntnsPsngr_D_Stat;
PROPERTYTYPE(SeatIntnsPsngr_D_Stat, SeatIntnsPsngr_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatMasgPsngr_D_Stat;
PROPERTYTYPE(SeatMasgPsngr_D_Stat, SeatMasgPsngr_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatSwtchPsgr_B_Stat;
PROPERTYTYPE(SeatSwtchPsgr_B_Stat, SeatSwtchPsgr_B_StatType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatFnDrv_D_Rq;
PROPERTYTYPE(SeatFnDrv_D_Rq, SeatFnDrv_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatFnChngDrv2_D_Rq;
PROPERTYTYPE(SeatFnChngDrv2_D_Rq, SeatFnChngDrv2_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatMasgDrv_D_Rq;
PROPERTYTYPE(SeatMasgDrv_D_Rq, SeatMasgDrv_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatFnPsgr_D_Rq;
PROPERTYTYPE(SeatFnPsgr_D_Rq, SeatFnPsgr_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatFnChngPsgr2_D_Rq;
PROPERTYTYPE(SeatFnChngPsgr2_D_Rq, SeatFnChngPsgr2_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatMasgPsngr_D_Rq;
PROPERTYTYPE(SeatMasgPsngr_D_Rq, SeatMasgPsngr_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatFnDfaltDrv_B_Rq;
PROPERTYTYPE(SeatFnDfaltDrv_B_Rq, SeatFnDfaltDrv_B_RqType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatFnDfaltPsgr_B_Rq;
PROPERTYTYPE(SeatFnDfaltPsgr_B_Rq, SeatFnDfaltPsgr_B_RqType, BasicPropertyType<uint16_t>, uint16_t)

static const Property StmsLmbrPsgr_D_Stat;
PROPERTYTYPE(StmsLmbrPsgr_D_Stat, StmsLmbrPsgr_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatLmbrLoPsgr_Pc_Actl;
PROPERTYTYPE(SeatLmbrLoPsgr_Pc_Actl, SeatLmbrLoPsgr_Pc_ActlType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatLmbrMidPsgr_Pc_Actl;
PROPERTYTYPE(SeatLmbrMidPsgr_Pc_Actl, SeatLmbrMidPsgr_Pc_ActlType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatLmbrUpPsgr_Pc_Actl;
PROPERTYTYPE(SeatLmbrUpPsgr_Pc_Actl, SeatLmbrUpPsgr_Pc_ActlType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatIntnsDrv_D_Stat;
PROPERTYTYPE(SeatIntnsDrv_D_Stat, SeatIntnsDrv_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatMasgDrv_D_Stat;
PROPERTYTYPE(SeatMasgDrv_D_Stat, SeatMasgDrv_D_StatType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatSwtchDrv_B_Stat;
PROPERTYTYPE(SeatSwtchDrv_B_Stat, SeatSwtchDrv_B_StatType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatLmbrLoDrv_Pc_Actl;
PROPERTYTYPE(SeatLmbrLoDrv_Pc_Actl, SeatLmbrLoDrv_Pc_ActlType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatLmbrMidDrv_Pc_Actl;
PROPERTYTYPE(SeatLmbrMidDrv_Pc_Actl, SeatLmbrMidDrv_Pc_ActlType, BasicPropertyType<uint16_t>, uint16_t)

static const Property SeatLmbrUpDrv_Pc_Actl;
PROPERTYTYPE(SeatLmbrUpDrv_Pc_Actl, SeatLmbrUpDrv_Pc_ActlType, BasicPropertyType<uint16_t>, uint16_t)

//Camera

static const Property Pers1OptIn_B_Stats;
PROPERTYTYPE(Pers1OptIn_B_Stats, Pers1OptIn_B_StatsType, BasicPropertyType<uint16_t>, uint16_t)

static const Property Pers2OptIn_B_Stats;
PROPERTYTYPE(Pers2OptIn_B_Stats, Pers2OptIn_B_StatsType, BasicPropertyType<uint16_t>, uint16_t)

static const Property Pers3OptIn_B_Stats;
PROPERTYTYPE(Pers3OptIn_B_Stats, Pers3OptIn_B_StatsType, BasicPropertyType<uint16_t>, uint16_t)

static const Property Pers4OptIn_B_Stats;
PROPERTYTYPE(Pers4OptIn_B_Stats, Pers4OptIn_B_StatsType, BasicPropertyType<uint16_t>, uint16_t)

static const Property PersStore_D_Rq;
PROPERTYTYPE(PersStore_D_Rq, PersStore_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

static const Property CtrStkDsplyOp_D_Rq;
PROPERTYTYPE(CtrStkDsplyOp_D_Rq, CtrStkDsplyOp_D_RqType, BasicPropertyType<uint16_t>, uint16_t)

static const Property CtrStkFeatConfigActl;
PROPERTYTYPE(CtrStkFeatConfigActl, CtrStkFeatConfigActlType, BasicPropertyType<uint16_t>, uint16_t)

static const Property CtrStkFeatNoActl;
PROPERTYTYPE(CtrStkFeatNoActl, CtrStkFeatNoActlType, BasicPropertyType<uint16_t>, uint16_t)

static const Property CtrStkPersIndex_D_Actl;
PROPERTYTYPE(CtrStkPersIndex_D_Actl, CtrStkPersIndex_D_ActlType, BasicPropertyType<uint16_t>, uint16_t)

static const Property Personality_IPMB_Data_HS3;
PROPERTYTYPE(Personality_IPMB_Data_HS3, Personality_IPMB_Data_HS3Type, BasicPropertyType<uint16_t>, uint16_t)


private:

	VehiclePropertyExt();

	static bool registerPropertyPriv(Property name, PropertyTypeFactoryCallback factory);
	//static PropertyList mCapabilities;
	//static std::map<Property, PropertyTypeFactoryCallback> registeredPropertyFactoryMap;
	static std::unique_ptr<VehiclePropertyExt> thereCanOnlyBeOne;
};


#endif // VEHICLEPROPERTYEXT_H


